@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.7.3.1';
+    return '1.7.4';
   }
 
   function GetHelp()
