@@ -245,6 +245,11 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('closehead_title', $this->GetPreference('closehead_title','0'));
    $this->smarty->assign('additional_title', $this->GetPreference('additional_title',''));
    $this->smarty->assign('stylesheet_title', $this->GetPreference('stylesheet_title','0'));
+   $this->smarty->assign('stylesheet_name', $this->GetPreference('stylesheet_name','0'));
+   $this->smarty->assign('stylesheet_nocombine', $this->GetPreference('stylesheet_nocombine','0'));
+   $this->smarty->assign('stylesheet_https', $this->GetPreference('stylesheet_https','0'));
+   $this->smarty->assign('stylesheet_templateid', $this->GetPreference('stylesheet_templateid','0'));
+   $this->smarty->assign('stylesheet_media', $this->GetPreference('stylesheet_media','0'));
    $this->smarty->assign('jquery_title', $this->GetPreference('jquery_title','0'));
    $this->smarty->assign('jquery_exclude', $this->GetPreference('jquery_exclude',''));
    $this->smarty->assign('jquery_include', $this->GetPreference('jquery_include',''));
