@@ -34,6 +34,7 @@ $smarty->assign('page_smarty_help',$this->Lang('page_smarty_help'));
 $smarty->assign('delimiter_title_help',$this->Lang('delimiter_title_help'));
 $smarty->assign('block_title_help',$this->Lang('block_title_help'));
 $smarty->assign('meta_block_title_help',$this->Lang('meta_block_title_help'));
+$smarty->assign('content_var_title_help',$this->Lang('content_var_title_help'));
 $smarty->assign('ogimage_title_help',$this->Lang('ogimage_title_help'));
 
 $smarty->assign('title_page_smarty',$this->Lang('page_smarty'));
@@ -48,6 +49,9 @@ $smarty->assign('input_delimiter_title',$this->CreateInputText($id,'delimiter_ti
 $smarty->assign('title_meta_block_title',$this->Lang('meta_block_title'));
 $smarty->assign('input_meta_block_title',$this->CreateInputText($id,'meta_block_title',$this->GetPreference('meta_block_title',''),50,255));
 
+$smarty->assign('title_content_var_title',$this->Lang('content_var_title'));
+$smarty->assign('input_content_var_title',$this->CreateInputText($id,'content_var_title',$this->GetPreference('content_var_title',''),50,255));
+
 $smarty->assign('title_block_title',$this->Lang('block_title'));
 $smarty->assign('input_block_title',$this->CreateInputText($id,'block_title',$this->GetPreference('block_title',''),50,255));
 
