@@ -138,7 +138,7 @@ $lang['analytics_select'] = 'Please select one';
 $lang['analytics_single'] = 'A single domain';
 $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
-$lang['propertyid_title'] = 'Web Property ID';
+$lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
 $lang['webmasterid_title'] = 'Webmaster meta verification key';
 $lang['pretty_title'] = 'Are pretty URLs enabled?';
 $lang['post_title'] = 'Search type POST being used?';
@@ -169,7 +169,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.1 26 February 2012. Minor bug fix.</li>
 <li>Version 1.7.2 26 February 2012. Minor bug fix.</li>
 <li>Version 1.7.3 27 February 2012. Added seperate cms_stylesheet and cms_jquery tabs.</li>
-<li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li></ul>';
+<li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li>
+<li>Version 1.7.4 27 February 2012. Minor bug fixes and removed non working stylesheet and jquery params to avoid confusion.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
